## VTILS

### Utility functions from VTILS  
  

from vtils.util import Cipher  
cipher = Cipher(key_text)  
t1 = cipher.encrypt(plain_text)  
t2 = cipher.decrypt(t1)  


### Encrypt File  
TBD


### Decrypt File  
TBD


## AWS Cloud Utils (AwsCloudtils) 

### Upload File  
TBD

### Download File  
TBD




